list_files

Function list_files 

pub fn list_files(config: &GrabConfig) -> GrabResult<Vec<String>>
Lists the files that would be included by dirgrab without reading their contents. Returns display paths (relative to repo root in Git mode, or target path otherwise).